within FlueGasTreatment.Reactions.SCM;
model SCM_BagFilter_NaHCO3_SO2_HCl_base
  extends FlueGasTreatment.Reactions.SCM.Templates.PartialShrinkingCoreModel;
  import Modelon.Math.Smoothing.regExp;
  import ThermalPower.FlueGasTreatment.Internal.Conversion.to_J;
  import Modelica.Constants.R;
  import Modelica.Constants.eps;
  import ThermalPower.FlueGasTreatment.Internal.Conversion.from_Nm3;

  Real dx_Bdt "Derivative of x_B";
  Real dx_Bdt_cg "Derivative of x_B normalized with gas concentration";
   Real drcdt "Derivative of rc";

  input Modelica.Units.SI.Radius rc "Radius of the core";
  Real tau[3];
equation
  x_B = 1-(rc/r0)^3;
  dx_Bdt_cg =1/sum(tau);//0.002;///c_g_in

  dx_Bdt = c_g_in*dx_Bdt_cg;
  drcdt = -1*r0^3/rc^2/3*dx_Bdt;
  tau[1]=1/3*tau_K*(max(Modelica.Constants.eps,1-x_B+Modelica.Constants.eps))^(-2/3);
  tau[2]=2*tau_D*((max(Modelica.Constants.eps,1-x_B+Modelica.Constants.eps))^(-1/3)-1);
  tau[3]=tau_M;
  annotation (Documentation(info="<html>


<html>
      <p>Shrinking Core Model (SCM) describes the amount of gaseous pollutant that is being captured by a particle of given size while the unreacted core is shrinking. Knowing the residence time of the particle in the reactor, the reactant conversion rate and the pollutant concentration in the gas can easily be computed.
      </p>
      
      <p>3 resistances in series:
<p><img src=\"modelica://ThermalPower/Resources/Images/FlueGasTreatment/SCM_resistance_implicit.png\"/></p>
<p><img src=\"modelica://ThermalPower/Resources/Images/FlueGasTreatment/SCM_resistance.png\"/></p>

<p>At given bulk gas concentration:
<ul><li> 
Dynamics of the conversion rate (or radius)</li><li>
Explicit integration at constant gas concentration</li></ul>
</p>
</html>



</html>"));
end SCM_BagFilter_NaHCO3_SO2_HCl_base;
