within FlueGasTreatment.Reactions.SCM.Templates;
model SCM_SPS_SO2HCl
  extends FlueGasTreatment.Reactions.SCM.Templates.PartialSCM(
      redeclare replaceable package Gas =
        ThermalPower.FlueGasTreatment.Internal.Media.Gases.ReactionGas_withAsh);
  import ThermalPower.FlueGasTreatment.Internal.Conversion.to_J;
  import Modelica.Constants.R;
  import Modelica.Constants.eps;
  import ThermalPower.FlueGasTreatment.Internal.Conversion.from_Nm3;

  import Modelon.Media.DataDefinitions.NasaData;
  input Modelica.Units.SI.Concentration c_g_in_so2=600*1e-6/from_Nm3(1,p,T)/Gas.MMC[3]
                                                    "SO2 concerntration in the ambient gas";  //annotation(dialog(Enable=true));

  input Modelica.Units.SI.Concentration c_g_in_hcl=600*1e-6/from_Nm3(1,p,T)/Gas.MMC[3]
                                                    "HCl concerntration in the ambient gas";// annotation(dialog(Enable=true));

  input Real x_B0(min = 0, max= 1)=0  "Initial conversion of calcium hydroxide ";

  replaceable record Sorbent =
      FlueGasTreatment.Records.Data.SCM_sorbent_CaOH2_SO2HCl
    constrainedby
    ThermalPower.FlueGasTreatment.Records.Data.SCM_sorbent_NaHCO3_SO2_HCl;
  Sorbent sorbent;

  replaceable model SCM_SO2 =
      FlueGasTreatment.Reactions.SCM.SCM_BagFilter_NaHCO3_SO2_HCl_base (
      c_g_in=c_g_in_so2,
      T=T,
      p=p,
      rc=rc_so2,
      redeclare record Sorbent = Sorbent,
      x_B0=x_B0,
      De0=SCM_const_sps_SO2.De0,
      E_rec=SCM_const_sps_SO2.E_rec,
      k_s0=SCM_const_sps_SO2.k_s0,
      k_g=SCM_const_sps_SO2.k_g) constrainedby
    FlueGasTreatment.Reactions.SCM.Templates.PartialSCM
                                        annotation (choicesAllMatching);

    SCM_SO2 scm_so2;

    replaceable model SCM_HCl =
      FlueGasTreatment.Reactions.SCM.SCM_BagFilter_NaHCO3_SO2_HCl_base (
      T=T,
      p=p,
      c_g_in=c_g_in_hcl,
      rc=rc_hcl,
      redeclare record Sorbent = Sorbent,
      x_B0=x_B0,
      De0=SCM_const_sps_HCl.De0,
      E_rec=SCM_const_sps_HCl.E_rec,
      k_s0=SCM_const_sps_HCl.k_s0,
      k_g=SCM_const_sps_HCl.k_g) constrainedby
    FlueGasTreatment.Reactions.SCM.Templates.PartialSCM
                                        annotation (choicesAllMatching);

    SCM_HCl scm_hcl;

   input Modelica.Units.SI.Diameter rc_so2;
   input Modelica.Units.SI.Diameter rc_hcl;

  input Real  x_B;
  input Real y1 = 1 "Molar ratio of sorbent that has reacted with gas 1";

  Modelica.Units.SI.Concentration c_r_out = sorbent.c_s*(1-x_B); // reactant concnerntration
  Modelica.Units.SI.Density rho_r_out=sorbent.rho_s*(1 - x_B);
  Modelica.Units.SI.Density rho_s_out=sorbent.rho_s*((1 - x_B) + x_B/sorbent.M_s
      *(sorbent.M_p*y1*sorbent.RC_Na2SO3 + sorbent.M_p_2*(1 - y1)*sorbent.RC_NaCl));

   replaceable FlueGasTreatment.Records.Data.SCM_ReactionConstants
    SCM_const_sps_SO2 constrainedby
    FlueGasTreatment.Records.Data.SCM_ReactionConstants
    annotation (choicesAllMatching, Placement(transformation(extent={{-36,28},{-16,
            48}})));
   replaceable FlueGasTreatment.Records.Data.SCM_ReactionConstants
    SCM_const_sps_HCl constrainedby
    FlueGasTreatment.Records.Data.SCM_ReactionConstants
    annotation (choicesAllMatching, Placement(transformation(extent={{-36,-10},{
            -16,10}})));
  annotation (Documentation(info="<html>
      <p>Shrinking Core Model (SCM) describes the amount of gaseous pollutant that is being captured by a particle of given size while the unreacted core is shrinking. Knowing the residence time of the particle in the reactor, the reactant conversion rate and the pollutant concentration in the gas can easily be computed.
      </p>
      
      <p>3 resistances in series:
<p><img src=\"modelica://ThermalPower/Resources/Images/FlueGasTreatment/SCM_resistance_implicit.png\"/></p>
<p><img src=\"modelica://ThermalPower/Resources/Images/FlueGasTreatment/SCM_resistance.png\"/></p>

<p>At given bulk gas concentration:
<ul><li> 
Dynamics of the conversion rate (or radius)</li><li>
Explicit integration at constant gas concentration</li></ul>
</p>
  <p>Static SCM equations
<ul>
<li>Conversion rate to express amount and volume of unreacted sorbent material
</li>
<p><img src=\"modelica://ThermalPower/Resources/Images/FlueGasTreatment/stacticSCM.png\"/></p>
<li>Density of used sorbent particle
</li>
<p><img src=\"modelica://ThermalPower/Resources/Images/FlueGasTreatment/stacticSCM_density.png\"/></p>
<p><img src=\"modelica://ThermalPower/Resources/Images/FlueGasTreatment/stacticSCM_density2.png\"/></p>
<li>Assuming stoichiometry Sp: 1 mol of sorbent gives Sp moles of product can be generalized to several products. 
</li>
<p><img src=\"modelica://ThermalPower/Resources/Images/FlueGasTreatment/stacticSCM_product.png\"/></p>
</ul></p>


</html>"));
end SCM_SPS_SO2HCl;
