within FlueGasTreatment.Records;
model InputData "Typical input data"
   replaceable package Gas =
      ThermalPower.FlueGasTreatment.Internal.Media.Gases.ReactionGas_withAsh
    constrainedby ThermalPower.SeparationProcess.Media.Gases.IdealFlueGas "X: (CO2, H20, O2, N2, ash) and C: (NO, NH3, SO2, HCl) "
                                                annotation (choicesAllMatching);
  import ThermalPower.FlueGasTreatment.Internal.Conversion.from_Nm3;
  import ThermalPower.FlueGasTreatment.Internal.Conversion.from_11oxygenDry;
  final parameter Real[Gas.nC] mmc=Gas.MMC;
  final parameter Real[Gas.nS] mmx=Gas.MMX;

    // Inputs
  input Modelon.Media.Units.AbsolutePressure p=101300    "Pressure" annotation(Dialog(group="Parameters"));
   input Modelica.Units.SI.Temperature T = 473 "Inlet fluegas temperature" annotation(Dialog(group="Parameters"));

  // Chimney
   input Modelica.Units.SI.Temperature T_chimney = 473 "Fluegas temperature at chimney" annotation(Dialog(group="Chimney conditions"));
   input Real V_flow_fluegas = 50e3 "[Nm3/h] fluegas flow at chimney, raw data" annotation(Dialog(group="Chimney conditions"));
  input Real c_H2O_chimney = 20 "H2O conc at chimney, 0-100% vol" annotation(Dialog(group="Chimney conditions"));

  // X vector
 input Real c_CO2 = 9 "CO2 conc 0-100% vol, dry" annotation(Dialog(group="Concentrations"));
 input Real c_H2O = 20 "H2O conc 0-100% vol" annotation(Dialog(group="Concentrations"));
 input Real c_O2 =  10.5 "O2 conc 0-100% vol, dry" annotation(Dialog(group="Concentrations"));
 //input Real c_N2 "N2 conc % 0-100 vol, dry" annotation(Dialog(group="Concentrations"));
 input Real c_ash = 2500 "ash conc [mg/Nm3] dry at 11% O2" annotation(Dialog(group="Concentrations"));

 // C vector
 input Real c_NO "NO conc [mg/Nm3] dry at 11% O2" annotation(Dialog(group="Concentrations"));
 input Real c_NH3 = 0 "NH3 conc [mg/Nm3] dry at 11% O2" annotation(Dialog(group="Concentrations"));
 input Real c_SO2 "SO2 conc [mg/Nm3] dry at 11% O2" annotation(Dialog(group="Concentrations"));
 input Real c_HCl "HCl conc [mg/Nm3] dry at 11% O2" annotation(Dialog(group="Concentrations"));

Modelica.Units.SI.Density density = Gas.density(Gas.setState_pTX(p, T, cat(1,X_wet_uncorrected[1:4],{0})));
Modelica.Units.SI.Density density_chimney = Gas.density(Gas.setState_pTX(p, T_chimney, cat(1,X_wet_uncorrected[1:4],{0})));
Modelica.Units.SI.MassFlowRate m_flow_fluegas = from_Nm3(V_flow_fluegas/3600, p, T_chimney)*density_chimney;

Modelica.Units.SI.MassFlowRate[Gas.nS] mX_flow = m_flow_fluegas*X_wet_uncorrected;
Modelica.Units.SI.MolarFlowRate[Gas.nS] nX_flow= {mX_flow[i]/max(Modelica.Constants.eps, Gas.MMX[i]) for i in 1:Gas.nS};
Modelica.Units.SI.MassFlowRate[Gas.nC] mC_flow = m_flow_fluegas*C_wet_uncorrected;
Modelica.Units.SI.MolarFlowRate[Gas.nC] nC_flow= {mC_flow[i]/max(Modelica.Constants.eps, Gas.MMC[i]) for i in 1:Gas.nC};

  Modelica.Blocks.Sources.RealExpression y_CO2_dry_uncorr(y=c_CO2/100)
    annotation (Placement(transformation(extent={{-94,70},{-46,90}})));
  Modelica.Blocks.Sources.RealExpression y_H2O(y=c_H2O/100)
    annotation (Placement(transformation(extent={{-96,18},{-48,38}})));
  Modelica.Blocks.Sources.RealExpression y_O2_dry(y=c_O2/100)
    annotation (Placement(transformation(extent={{-94,-4},{-46,16}})));
  Modelica.Blocks.Sources.RealExpression y_N2_wet_uncorr(y=1 - sum(
        y_wet_uncorr.y))
    annotation (Placement(transformation(extent={{-94,-26},{-46,-6}})));
  Modelica.Blocks.Routing.Multiplex3 y_wet_uncorr
    annotation (Placement(transformation(extent={{58,26},{82,50}})));
  Modelica.Blocks.Sources.RealExpression y_ash_dry_uncorr(y=c_ash)
    annotation (Placement(transformation(extent={{-94,-48},{-46,-28}})));
  Modelica.Blocks.Math.Add add(k2=-1)
    annotation (Placement(transformation(extent={{-24,34},{-4,54}})));
  Modelica.Blocks.Sources.Constant const(k=1)
    annotation (Placement(transformation(extent={{-92,46},{-72,66}})));
  Modelica.Blocks.Math.Product y_CO2_wet_uncorr
    annotation (Placement(transformation(extent={{18,64},{38,84}})));
  Modelica.Blocks.Math.Product y_O2_wet_uncorr
    annotation (Placement(transformation(extent={{16,2},{36,22}})));
  ThermalPower.SeparationProcess.Sensors.fromConcentrationToMass
    y_ash_wet_uncorr(
    n=1,
    concentrationType=ThermalPower.SeparationProcess.Sensors.Types.ConcentrationType.correctedNm3,
    p=p,
    T=T,
    humidity=c_H2O/100,
    density=density,
    Xv_O2=c_O2/100)
    annotation (Placement(transformation(extent={{-30,-48},{-12,-30}})));

  Modelica.Blocks.Interfaces.RealOutput X_wet_uncorrected[5]
    "Connector of Real output signals"
    annotation (Placement(transformation(extent={{186,48},{206,68}}),
        iconTransformation(extent={{186,48},{206,68}})));
  ThermalPower.SeparationProcess.Sensors.fromConcentrationToMass
    y_ash_wet_uncorr1(
    n=4,
    concentrationType=ThermalPower.SeparationProcess.Sensors.Types.ConcentrationType.correctedNm3,
    p=p,
    T=T,
    humidity=c_H2O/100,
    density=density,
    Xv_O2=c_O2/100)
    annotation (Placement(transformation(extent={{-30,-82},{-10,-62}})));

  Modelica.Blocks.Sources.RealExpression traces_mgNm3_dry_11O2[4](y={c_NO,
        c_NH3,c_SO2,c_HCl})
    annotation (Placement(transformation(extent={{-96,-84},{-48,-64}})));
  Modelica.Blocks.Interfaces.RealOutput C_wet_uncorrected[4]
    "Connector of Real output signals"
    annotation (Placement(transformation(extent={{188,-82},{208,-62}}),
        iconTransformation(extent={{188,-82},{208,-62}})));
  Modelica.Blocks.Routing.Multiplex2 multiplex2_1(n1=4)
    annotation (Placement(transformation(extent={{158,6},{178,26}})));
  Modelica.Blocks.Routing.Multiplex2 y_wet_uncorr1(n1=3)
    annotation (Placement(transformation(extent={{94,-10},{118,14}})));
  Modelica.Blocks.Sources.RealExpression y_CO2_dry_uncorr1[4](y=
        Modelon.Media.Functions.moleToMassFractions(y_wet_uncorr1.y, Gas.MMX[
        1:4]))
    annotation (Placement(transformation(extent={{92,18},{140,38}})));
equation
  connect(const.y, add.u1)
    annotation (Line(points={{-71,56},{-48,56},{-48,50},{-26,50}},
                                                 color={0,0,127}));
  connect(y_H2O.y, add.u2) annotation (Line(points={{-45.6,28},{-42,28},{-42,38},
          {-26,38}}, color={0,0,127}));
  connect(y_CO2_dry_uncorr.y, y_CO2_wet_uncorr.u1)
    annotation (Line(points={{-43.6,80},{16,80}}, color={0,0,127}));
  connect(add.y, y_CO2_wet_uncorr.u2) annotation (Line(points={{-3,44},{14,44},
          {14,68},{16,68}}, color={0,0,127}));
  connect(y_O2_wet_uncorr.u1, y_CO2_wet_uncorr.u2)
    annotation (Line(points={{14,18},{14,68},{16,68}}, color={0,0,127}));
  connect(y_O2_dry.y, y_O2_wet_uncorr.u2)
    annotation (Line(points={{-43.6,6},{14,6}}, color={0,0,127}));
  connect(y_ash_dry_uncorr.y, y_ash_wet_uncorr.C[1])
    annotation (Line(points={{-43.6,-38},{-42,-38},{-42,-42},{-36,-42},{-36,-39},
          {-28.2,-39}},                              color={0,0,127}));
  connect(y_O2_wet_uncorr.y, y_wet_uncorr.u3[1]) annotation (Line(points={{37,12},
          {58,12},{58,29.6},{55.6,29.6}},     color={0,0,127}));
  connect(y_CO2_wet_uncorr.y, y_wet_uncorr.u1[1]) annotation (Line(points={{39,74},
          {46,74},{46,46.4},{55.6,46.4}},     color={0,0,127}));
  connect(y_H2O.y, y_wet_uncorr.u2[1]) annotation (Line(points={{-45.6,28},{-42,
          28},{-42,38},{-32,38},{-32,30},{46,30},{46,38},{55.6,38}},
                                  color={0,0,127}));
  connect(multiplex2_1.y, X_wet_uncorrected) annotation (Line(points={{179,16},
          {192,16},{192,42},{198,42},{198,58},{196,58}}, color={0,0,127}));
  connect(traces_mgNm3_dry_11O2.y, y_ash_wet_uncorr1.C) annotation (Line(
        points={{-45.6,-74},{-44,-74},{-44,-76},{-36,-76},{-36,-72},{-28,-72}},
        color={0,0,127}));
  connect(y_wet_uncorr1.u1, y_wet_uncorr.y) annotation (Line(points={{91.6,
          9.2},{91.6,14},{88,14},{88,38},{83.2,38}}, color={0,0,127}));
  connect(y_wet_uncorr1.u2[1], y_N2_wet_uncorr.y) annotation (Line(points=
         {{91.6,-5.2},{91.6,-10},{-34,-10},{-34,-20},{-43.6,-20},{-43.6,-16}},
        color={0,0,127}));
  connect(y_ash_wet_uncorr.X, multiplex2_1.u2)
    annotation (Line(points={{-13.8,-39},{150,-39},{150,10},{156,10}},
                                                            color={0,0,127}));
  connect(y_CO2_dry_uncorr1.y, multiplex2_1.u1) annotation (Line(points={{142.4,
          28},{150,28},{150,22},{156,22}},       color={0,0,127}));
  connect(y_ash_wet_uncorr1.X, C_wet_uncorrected) annotation (Line(points={{-12,-72},
          {198,-72}},                           color={0,0,127}));
annotation(Documentation(revisions="<html><!--COPYRIGHT--></html>"), Diagram(
        coordinateSystem(extent={{-100,-100},{200,100}}),
        graphics={Text(
          extent={{134,98},{202,84}},
          textColor={28,108,200},
          textString="X: (CO2, H20, O2, N2, ash) "), Text(
          extent={{130,-86},{198,-100}},
          textColor={28,108,200},
          textString="C: (NO, NH3, SO2, HCl)")}),
    Icon(coordinateSystem(extent={{-100,-100},{200,100}}), graphics={Rectangle(
          extent={{-100,100},{192,-100}},
          lineColor={0,0,0},
          fillPattern=FillPattern.Solid,
          fillColor={255,255,255}),
        Text(
          extent={{80,-20},{-80,20}},
          lineColor={0,0,127},
          textString="%name",
          origin={42,8},
          rotation=180)}));
end InputData;
