within FlueGasTreatment.SubComponents.BagFilter;
model Bagfilter
  extends ThermalPower.FlueGasTreatment.Internal.Icons.base_bag_icon;
  extends ThermalPower.FlueGasTreatment.Internal.Icons.bag_filter_icon;
  replaceable package Gas =
      ThermalPower.FlueGasTreatment.Internal.Media.Gases.ReactionGas_withAsh
    constrainedby ThermalPower.SeparationProcess.Media.Gases.IdealFlueGas
                                                                      annotation (
      choicesAllMatching=true);
        replaceable record Sorbent =
      FlueGasTreatment.Records.Data.SCM_sorbent_CaOH2_SO2HCl annotation (
      choicesAllMatching=true);
    Sorbent sorbent;
      parameter Modelica.Units.SI.Pressure dp_lim(displayUnit="Pa")=1500
                                                    "Limitation of dp";

  BagFilter_NaHCO3_SO2_HCl                                    bagFilter(
    Tstart=Tstart,
    cal_HCl=cal_HCl,
    redeclare package Gas = Gas,
    initOpt=initOpt,
    pstart=pstart,
    Xstart=Xstart,
    m_flow_start=m_flow_start,
    Cstart=Cstart,
    redeclare record BedGeo = BedGeo,
    redeclare model Reaction = Reaction,
    redeclare record Sorbent = Sorbent,
    x_left=x_left,
    m_flow_ash=ESP.m_flow_clt[5],
    recirculation_on=recirculation_on,
    dp_lim=dp_lim,
    recycle=recycle,
    redeclare model Friction_filter = Friction_filter,
    cal_SO2=cal_SO2)
    annotation (Placement(transformation(extent={{-60,-66},{-26,-26}})));
  FlueGasTreatment.SubComponents.BagFilter.ESP ESP(
    redeclare package Gas = Gas,
    k_eta=k_eta,
    T_start=Tstart,
    X_start=Xstart,
    p_start=p_start_ESP,
    C_start=Cstart,
    gamma=gamma_ESP)
               annotation (Placement(transformation(extent={{-14,-68},{30,-24}})));
    ThermalPower.FlueGas.FlowResistances.FrictionLoss  frictionLoss1(redeclare
      model Friction = Friction,
                      redeclare package Medium = Gas)                                                                                                                                                           annotation(Placement(transformation(extent = {{4.0,-10.0},{24.0,10.0}},rotation = 0.0,origin={42,-48})));
  ThermalPower.SeparationProcess.Interfaces.VolumePort feed(redeclare package
      Medium = Gas) annotation (Placement(transformation(extent={{-90,-8},{-70,12}}),
        iconTransformation(extent={{-90,-8},{-70,12}})));
  ThermalPower.SeparationProcess.Interfaces.FlowPort
                                        drain(redeclare package Medium = Gas)
    annotation (Placement(transformation(extent={{70,-10},{90,10}}),
        iconTransformation(extent={{70,-10},{90,10}})));
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a q annotation (Placement(
        transformation(extent={{-10,-8},{10,12}}), iconTransformation(extent={{-10,
            -8},{10,12}})));
  parameter Real cal_HCl=0.3 "Calibration factor for HCl resistance";
  parameter Real cal_SO2=0.9 "Calibration factor for SO2 resistance";
  replaceable record BedGeo =
      ThermalPower.FlueGasTreatment.Records.Geometry.Geo_BagFilter (Ac=1400, Vtot=200)
    constrainedby ThermalPower.FlueGasTreatment.Records.Geometry.Geo_BagFilter "Geometry"
    annotation (choicesAllMatching=true);
  parameter Boolean recirculation_on=false
    "If true, recirculation of sorbent is used";
  replaceable model Friction_filter =
      ThermalPower.FlueGasTreatment.Internal.Friction.Friction_BagFilter (v_flow_gas0=70, H_cake_max=0.7e-5, dp_cake_max=1500, dp_filter_0=500)
    constrainedby
    ThermalPower.FlueGasTreatment.Internal.Friction.Friction_BagFilter
    "Friction loss by the cake" annotation (choicesAllMatching=true);
  parameter Real k_eta=3e-9 "[1/V^2] ESP efficiency constant"  annotation (Dialog(group="Ash removal"));
  parameter Real recycle=1 "Recycle percentage";
  parameter Real x_left=0.1 "0-1, portion of the cake that stays on the filter";
  replaceable model Friction =
      Modelon.ThermoFluid.FlowResistances.FrictionModels.QuadraticOperatingPointLoss
      (                                                                               m_flow0=16);
  parameter Modelon.Media.Units.AbsolutePressure pstart=104000
    "Pressure start value" annotation (Dialog(tab="Initialization"));
  parameter Modelon.Media.Units.MassFraction Xstart[Gas.nS]={0.1,0.1,0.05,0.7,0.5}
    "Gas composition start value" annotation (Dialog(tab="Initialization"));
  parameter Modelica.Units.SI.MassFlowRate m_flow_start=50
    "Nominal mass flowrate (total)" annotation (Dialog(tab="Initialization"));
  replaceable model Reaction =
      Reactions.SCM.Templates.SCM_SPS_SO2HCl (redeclare Records.Data.SCM_ReactionConstants SCM_const_sps_SO2(k_g=0.1, k_s0=0.1), redeclare Records.Data.SCM_constants_SO2 SCM_const_sps_HCl)
    constrainedby Reactions.SCM.SCM_BagFilter_NaHCO3_SO2_HCl annotation (
      choicesAllMatching=true,Dialog(tab="Reaction"));
  parameter Modelon.Media.Units.Temperature Tstart=453.15
    "Temperature start value" annotation (Dialog(tab="Initialization"));
  parameter Modelica.Units.SI.Pressure p_start_ESP=100000 "Pressure start value for ESP" annotation (Dialog(tab="Initialization"));
    parameter Modelon.Media.Units.ExtraProperty Cstart[Gas.nC]=fill(1e-6, Gas.nC)
                          "Trace mass start value" annotation(Dialog(tab= "Initialization"));
  parameter Real gamma_ESP=0.4 "Calibration factor for ESP" annotation (Dialog(group="Ash removal"));
  ThermalPower.FlueGasTreatment.Internal.Interfaces.cake_out sorbent_out
    annotation (Placement(transformation(extent={{-8,-116},{12,-96}}),
        iconTransformation(extent={{-8,-116},{12,-96}})));
  ThermalPower.FlueGasTreatment.Internal.Interfaces.cake_in sorbent_in
    annotation (Placement(transformation(extent={{-98,66},{-78,86}})));
  parameter Modelon.ThermoFluid.Choices.InitOptions initOpt=Modelon.ThermoFluid.Choices.InitOptions.initialValues
    "Initialisation option" annotation (Dialog(tab="Initialization"));
equation
  connect(bagFilter.drain,ESP. feed) annotation (Line(points={{-29.06,-46},{-9.6,
          -46}},            color={85,170,255}));
  connect(ESP.drain,frictionLoss1. feed)
    annotation (Line(points={{26.04,-46},{26.04,-48},{46,-48}},
                                                  color={85,170,255}));
  connect(bagFilter.feed, feed) annotation (Line(points={{-56.6,-46},{-80,-46},{
          -80,2}}, color={85,170,255}));
  connect(frictionLoss1.drain, drain) annotation (Line(points={{66,-48},{80,-48},
          {80,0}},           color={0,191,0}));
  connect(bagFilter.q, q)
    annotation (Line(points={{-43,-46},{-43,2},{0,2}}, color={191,0,0}));
  connect(bagFilter.sorbent_out, sorbent_out) annotation (Line(points={{-43,-65.2},
          {-43,-78.6},{2,-78.6},{2,-106}}, color={28,108,200}));
  connect(bagFilter.sorbent_in, sorbent_in) annotation (Line(points={{-56.6,-30.4},
          {-56.6,22.8},{-88,22.8},{-88,76}}, color={28,108,200}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)));
end Bagfilter;
