within FlueGasTreatment.SubComponents.BagFilter;
partial model PartialBagVolume "Partial model of bag volume"
  extends ThermalPower.FlueGasTreatment.Internal.Icons.base_bag_icon;
  extends ThermalPower.FlueGasTreatment.Internal.Template.PartialVolume(
      redeclare replaceable package Gas =
        ThermalPower.FlueGasTreatment.Internal.Media.Gases.ReactionGas_withAsh);
  import Modelica.Constants.R;

     constant Integer SO2 = 3;
     //desulfurization
     replaceable model Reaction =
      FlueGasTreatment.Reactions.SCM.Templates.PartialSCM constrainedby
    FlueGasTreatment.Reactions.SCM.Templates.PartialSCM annotation (Dialog(tab=
          "Reactions"),
      choicesAllMatching);
       replaceable record Sorbent =
      ThermalPower.FlueGasTreatment.Records.Data.SCM_sorbent_CAOH2
    constrainedby ThermalPower.FlueGasTreatment.Records.Data.SCM_sorbent_CAOH2
    annotation (Dialog(group="Sorbents"), choicesAllMatching=true);
  Sorbent sorbent;

   Modelica.Units.SI.MassFlowRate m_flow_s_in = sorbent_in.m_sorbent  "Mass flow rate of sorbent at the inlet";
   Real x_B_in = sorbent_in.x_B "Conversion rate at inlet";
 Modelica.Units.SI.MassFlowRate m_flow_r_in = rho_r_in*vol_flow_s_in  "Mass flow rate of pure Reactant at the inlet";
  Modelica.Units.SI.VolumeFlowRate vol_flow_r_in = (1-x_B_in)*vol_flow_s_in "Volume flow rate of the pure reactant at the inlet";
  Modelica.Units.SI.VolumeFlowRate vol_flow_s_in = m_flow_s_in/rho_s_in "Total volume flow rate of sorbent particles at the inlet";

 Modelica.Units.SI.Density rho_r_in = sorbent.rho_s*(1-x_B_in) "Density of Reactant in the particle at the inlet";
 Modelica.Units.SI.Density rho_s_in;  // Wrong if sevral products!!!

  //gas
  Modelica.Units.SI.Concentration c_g_in "Concerntraion of SO2 at the inlet";
  Real x_B_out "Conversion at the outlet";
  Real effective_RS;
 constant Integer Ash = 5; //get the index

   parameter Modelica.Units.SI.AmountOfSubstance[Gas.nS] Zx_start=Ztot_start*y_start "Initial component moles";
 final parameter Real[Gas.nS] y_start = if sum({Xstart[i]^2 for i in 1:Gas.nS})<1e-15 then Xstart else Gas.massToMoleFractions(Xstart, Gas.MMX);
  parameter Modelica.Units.SI.AmountOfSubstance Ztot_start=pstart*geo.Vtot/(R*Tstart)
    "Initial total moles";
  ThermalPower.FlueGasTreatment.Internal.Interfaces.cake_in sorbent_in
    annotation (Placement(transformation(extent={{-90,68},{-70,88}}),
        iconTransformation(extent={{-90,68},{-70,88}})));
  ThermalPower.FlueGasTreatment.Internal.Interfaces.cake_out sorbent_out
    annotation (Placement(transformation(extent={{-10,-106},{10,-86}}),
        iconTransformation(extent={{-10,-106},{10,-86}})));
protected
  Modelica.Units.SI.MolarMass MM "Molar mass of the Gas mixture";

initial equation

  Zx[1:Gas.nS-1]=Zx_start[1:Gas.nS-1];
equation
  X=X_i;
  for i in 1:Gas.nS loop
    dZ[i] = dMX[i]/Gas.MMX[i];
    der(Zx[i])=dZ[i];
  end for;
  Ztot = sum(Zx[:]);

  MM=if sum({X_i[i]^2 for i in 1:Gas.nS})<1e-15 then 0 else  1/(X_i[:]*(ones(Gas.nS)./Gas.MMX));
  c_g_in = C_i[SO2] /Gas.MMC[SO2]/ (1/MM*R*T/p); //"[mol/m3]"
  Z = Modelon.Media.Functions.massToMoleFractions(X_o, Gas.MMX);
  annotation (Icon(graphics={
        Text(
          extent={{80,-20},{-80,20}},
          lineColor={0,0,127},
          textString="%name",
          origin={-2,120},
          rotation=180)}));
end PartialBagVolume;
