within FlueGasTreatment.Tests;
model BagFilter_LW_SO2HCl
  "SCM tests, lime water for SO2 and HCl removal without recirculation"
  extends Modelon.Icons.Experiment;
  import ThermalPower.FlueGasTreatment.Internal.Conversion.to_11oxygenDry;
   import ThermalPower.FlueGasTreatment.Internal.Conversion.from_11oxygenDry;
 import ThermalPower.FlueGasTreatment.Internal.Conversion.from_Nm3;
 replaceable package Gas =
      ThermalPower.FlueGasTreatment.Internal.Media.Gases.ReactionGas_withAsh
    constrainedby ThermalPower.SeparationProcess.Media.Gases.IdealFlueGas
                                                                      annotation (
      choicesAllMatching=true);
  Real x_p1=summary.x_salt_SO3*summary.m_flow_cake/(max(1e-5,summary.m_flow_s_out));
  Real x_p2=summary.x_salt_Cl*summary.m_flow_cake/(max(1e-5,summary.m_flow_s_out));
  Real m_fresh = inputData.dZ_in_sorbent*sorbent.M_s;
  ThermalPower.FlueGasTreatment.Sources.Flowsource_mass_traces
    flowsource_track_mass1(
    connectorInput_flow=true,
    connectorInput_T=true,
    connectorInput_X=true,
    X0=inputData.X0,
    redeclare package Fluid = Gas,
    m_flow0=inputData.m_flow_start,
    T0=inputData.Tstart,
    T_std=298.15,
    MX_start=fill(1/Gas.nS, Gas.nS),
    connectorInput_C=true)
    annotation (Placement(transformation(extent={{-186,28},{-166,48}})));
  ThermalPower.FlueGasTreatment.Sources.Reservoir_mass_traces
    reservoir_mass_traces(
    redeclare package Fluid = Gas,
    p0=inputData.pstart,
    T0=inputData.Tstart,
    N=1) annotation (Placement(transformation(extent={{232,30},{212,50}})));

  ThermalPower.SeparationProcess.Sensors.ConcentrationSensor concentration_in(
      redeclare package Fluid = Gas, concentrationType=ThermalPower.SeparationProcess.Sensors.Types.ConcentrationType.correctedNm3)
    annotation (Placement(transformation(extent={{-122,30},{-102,50}})));
  ThermalPower.SeparationProcess.Sensors.ConcentrationSensor concentration_out(
      redeclare package Fluid = Gas, concentrationType=ThermalPower.SeparationProcess.Sensors.Types.ConcentrationType.correctedNm3)
    annotation (Placement(transformation(extent={{172,30},{192,50}})));
  parameter Modelica.Units.SI.Pressure dp_lim(displayUnit="Pa")=1500
                                                    "Limitation of dp";
  parameter Modelon.Media.Units.ExtraProperty Cstart[Gas.nC]={inputData.C_in_no,
      0,inputData.C_in_so2*0.8,inputData.C_in_so2*1.1}
                          "Trace mass start value";

  parameter Real k_g=0.05250056;

  replaceable record Sorbent =
      FlueGasTreatment.Records.Data.SCM_sorbent_CaOH2_SO2HCl
    annotation (choicesAllMatching=true);
    Sorbent sorbent;

  Modelica.Blocks.Continuous.FirstOrder HCl_filtered(
    k=1,
    T=30,
    y_start=0.05) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={82,-40})));

    ThermalPower.SeparationProcess.Sensors.MolarFlowSensor molarFlowSensor_in(
      redeclare package Fluid = Gas)
      annotation (Placement(transformation(extent={{-156,30},{-136,50}})));
    ThermalPower.SeparationProcess.Sensors.MolarFlowSensor molarFlowSensor_out(
      redeclare package Fluid = Gas)
      annotation (Placement(transformation(extent={{104,30},{124,50}})));
  Modelica.Blocks.Continuous.FirstOrder SO2_filtered(k=1, T=1600)
    annotation (Placement(transformation(extent={{206,64},{226,84}})));
  Modelica.Blocks.Continuous.FirstOrder n_SO2_filtered(k=1, T=100)
    annotation (Placement(transformation(extent={{146,74},{166,94}})));
  Modelica.Blocks.Continuous.FirstOrder n_HCl_filtered(k=1, T=100)
    annotation (Placement(transformation(extent={{152,110},{172,130}})));
  Modelica.Blocks.Math.Gain LW_kgh(k=3600)
    annotation (Placement(transformation(extent={{20,2},{40,22}})));
  ThermalPower.FlueGasTreatment.Records.Data.Summary_filter summary(
    Ash_in_sim=concentration_in.y[5],
    NOx_in_sim=concentration_in.y[6],
    NH3_in_sim=concentration_in.y[7],
    SO2_in_sim=concentration_in.y[8],
    HCl_in_sim=concentration_in.y[9],
    Ash_out_sim=concentration_out.y[5],
    NOx_out_sim=concentration_out.y[6],
    NH3_out_sim=concentration_out.y[7],
    SO2_out_sim=concentration_out.y[8],
    HCl_out_sim=concentration_out.y[9],
    m_flow_s_in=bagFilter.bagFilter.kpi.m_flow_s_in,
    m_flow_cake=bagFilter.bagFilter.kpi.m_flow_cake,
    recycle=bagFilter.bagFilter.kpi.recycle,
    m_flow_s_out=bagFilter.bagFilter.kpi.m_flow_s_out,
    x_salt_SO3=bagFilter.bagFilter.kpi.x_salt_SO3,
    x_salt_Cl=bagFilter.bagFilter.kpi.x_salt_Cl,
    x_ash=bagFilter.bagFilter.kpi.x_ash,
    x_fresh=bagFilter.bagFilter.kpi.x_fresh,
    period=bagFilter.bagFilter.kpi.period)
    annotation (Placement(transformation(extent={{39.28,145.52},{59.28,165.52}},rotation = 0.0,origin = {0.0,0.0})));
  FlueGasTreatment.SubComponents.SorbentSource sorbentSource
    annotation (Placement(transformation(extent={{-32,-8},{-52,12}})));
  FlueGasTreatment.Records.InputData plantData_in(
    T=Tab_input.y[6] + 273,
    T_chimney=Tab_input.y[16] + 273,
    V_flow_fluegas=Tab_input.y[15],
    c_H2O_chimney=Tab_input.y[11],
    c_H2O=Tab_input.y[11],
    c_O2=8,
    c_NO=400,
    c_SO2=Tab_input.y[2],
    c_HCl=max(0, Tab_input.y[1]),c_CO2 = 8,c_ash = 2000)
    annotation (Placement(transformation(extent={{-53.0,144.0},{-23.0,164.0}},rotation = 0.0,origin = {0.0,0.0})));
  FlueGasTreatment.Records.InputData plantData_out(
    T=Tab_input.y[6] + 273,
    T_chimney=Tab_input.y[16] + 273,
    V_flow_fluegas=Tab_input.y[15],
    c_H2O_chimney=Tab_input.y[11],
    c_H2O=Tab_input.y[11],
    c_O2=Tab_input.y[10],
    c_NO=Tab_input.y[13],
    c_SO2=Tab_input.y[9],
    c_HCl=Tab_input.y[8],c_CO2 = 8,c_ash = 2000)
    annotation (Placement(transformation(extent={{-14.319999999999993,143.12},{15.680000000000007,163.12}},rotation = 0.0,origin = {0.0,0.0})));
  Modelica.Blocks.Sources.CombiTimeTable Tab_input(table=[0,324,111,-1000,-1000,
        208,157,19,9,8,10,20,0.45,61,1.9,102264,176; 60,327,108,-1000,-1000,208,
        156,20,9,6,10,19,0.52,61,1.9,102397,176; 120,324,108,-1000,-1000,208,155,
        19,9,6,10,19,0.53,61,2,102157,176; 180,334,108,-1000,-1000,208,155,20,10,
        5,10,19,0.39,61,1.9,101978,176; 240,337,105,-1000,-1000,208,154,20,9,6,10,
        19,0.39,62,1.9,102331,176; 300,334,109,-1000,-1000,208,154,19,9,7,10,18,
        0.42,62,1.9,102330,176; 360,338,117,-1000,-1000,208,154,19,9,6,10,19,0.45,
        63,1.8,101685,176; 420,350,122,-1000,-1000,208,154,20,9,5,9,20,0.48,63,1.9,
        101888,176; 480,365,121,-1000,-1000,208,154,19,8,9,9,20,0.38,61,1.9,102373,
        176; 540,376,119,-1000,-1000,208,154,19,9,12,10,18,0.31,62,1.8,102223,176;
        600,383,118,-1000,-1000,208,153,20,10,12,10,18,0.53,65,1.8,102378,176; 660,
        380,117,-1000,-1000,208,153,19,10,11,10,18,0.53,65,1.8,101995,176; 720,381,
        117,-1000,-1000,208,154,19,11,8,10,18,0.43,63,1.8,102103,176; 780,376,117,
        -1000,-1000,208,153,19,10,7,10,19,0.43,64,1.8,102300,176; 840,366,113,-1000,
        -1000,207,153,20,10,7,10,18,0.36,66,1.9,102242,176; 900,358,112,-1000,-1000,
        207,153,19,10,5,11,18,0.32,67,1.9,102301,176; 960,357,111,-1000,-1000,207,
        154,18,10,4,11,18,0.34,67,1.9,101746,176; 1020,364,113,-1000,-1000,207,155,
        19,9,5,10,18,0.28,68,1.9,101841,176; 1080,364,111,-1000,-1000,207,155,19,
        9,7,10,18,0.28,67,1.9,102214,176; 1140,371,112,-1000,-1000,207,155,18,9,
        7,11,17,0.34,65,1.9,101376,176; 1200,382,113,-1000,-1000,207,155,19,9,7,
        10,18,0.36,64,1.9,101181,176; 1260,378,110,-1000,-1000,206,155,19,9,9,10,
        18,0.38,61,1.9,102216,176; 1320,386,108,-1000,-1000,206,155,19,9,10,10,17,
        0.34,58,1.8,101266,176; 1380,402,113,-1000,-1000,206,155,19,10,7,11,17,0.27,
        56,1.8,100011,176; 1440,414,115,-1000,-1000,206,154,19,10,7,10,18,0.33,57,
        1.8,100852,175; 1500,414,114,-1000,-1000,206,154,19,9,9,10,18,0.39,60,1.8,
        100236,175; 1560,402,110,-1000,-1000,205,153,19,10,8,11,17,0.33,60,1.9,101338,
        175; 1620,387,109,-1000,-1000,205,153,19,10,5,11,16,0.36,61,1.8,100583,175;
        1680,381,109,-1000,-1000,205,154,19,10,3,11,16,0.35,61,1.8,101239,175; 1740,
        373,111,-1000,-1000,205,154,19,9,3,11,17,0.33,64,1.9,100999,175; 1800,382,
        114,-1000,-1000,205,155,19,9,3,11,17,0.36,66,1.8,99181,175; 1860,390,113,
        -1000,-1000,205,156,19,8,4,10,18,0.27,65,1.8,98932,175; 1920,376,112,-1000,
        -1000,204,155,19,8,5,10,18,0.22,62,1.7,99596,175; 1980,366,110,-1000,-1000,
        204,155,19,8,5,10,17,0.23,60,1.7,99394,175; 2040,359,109,-1000,-1000,204,
        155,20,8,4,11,16,0.38,61,1.8,100150,175; 2100,355,110,-1000,-1000,204,155,
        19,8,3,11,16,0.43,64,1.8,100266,175; 2160,355,111,-1000,-1000,204,155,19,
        8,4,11,17,0.31,68,1.8,99758,175; 2220,359,114,-1000,-1000,204,156,19,8,4,
        10,17,0.27,70,1.7,99837,175; 2280,359,116,-1000,-1000,204,156,19,8,6,10,
        17,0.32,72,1.8,101485,175; 2340,364,116,-1000,-1000,204,156,18,8,7,11,17,
        0.35,75,1.8,99813,175; 2400,393,119,-1000,-1000,204,156,18,8,7,11,17,0.36,
        78,1.8,99633,175; 2460,413,119,-1000,-1000,204,155,18,8,8,11,18,0.49,79,
        1.8,99172,175; 2520,419,122,-1000,-1000,204,155,18,8,12,10,17,0.53,75,1.7,
        98869,175; 2580,425,125,-1000,-1000,204,156,19,9,15,11,16,0.38,68,1.8,99674,
        175; 2640,433,127,-1000,-1000,204,158,19,10,39,11,16,0.33,56,1.8,98281,175;
        2700,439,128,-1000,-1000,204,158,19,12,50,11,15,0.38,47,1.9,99274,175; 2760,
        445,128,-1000,-1000,204,155,19,15,23,11,17,0.43,46,1.8,98771,175; 2820,453,
        130,-1000,-1000,204,152,19,15,6,11,17,0.25,60,1.8,99076,175; 2880,457,129,
        -1000,-1000,204,151,19,12,1,10,18,0.13,67,1.8,100112,175; 2940,463,126,-1000,
        -1000,204,151,19,11,0,10,18,0.3,64,1.8,98309,175; 3000,480,123,-1000,-1000,
        204,152,20,9,0,10,18,0.46,68,1.8,99086,175; 3060,481,119,-1000,-1000,204,
        153,19,8,0,10,18,0.52,67,1.7,98107,175; 3120,488,115,-1000,-1000,203,154,
        19,7,0,10,18,0.39,66,1.7,97958,175; 3180,496,116,-1000,-1000,203,155,19,
        7,0,10,18,0.48,66,1.7,98357,175; 3240,513,118,-1000,-1000,203,155,19,7,0,
        10,17,0.63,57,1.7,96304,175; 3300,533,120,-1000,-1000,203,155,19,7,0,10,
        17,0.62,64,1.7,96470,175; 3360,543,120,-1000,-1000,203,155,19,6,1,10,18,
        0.54,71,1.6,96869,175; 3420,542,123,-1000,-1000,203,155,19,6,2,10,17,0.56,
        70,1.6,95955,175; 3480,536,121,-1000,-1000,202,154,19,7,1,10,17,0.54,68,
        1.6,97992,175; 3540,528,121,-1000,-1000,202,155,19,7,1,10,17,0.4,67,1.6,
        95742,175; 3600,528,123,-1000,-1000,202,155,19,6,1,10,17,0.31,64,1.6,95344,
        175; 3660,514,121,-1000,-1000,202,155,19,6,1,10,18,0.36,61,1.6,95119,175;
        3720,487,117,-1000,-1000,201,154,19,6,1,10,17,0.44,60,1.6,94841,175; 3780,
        461,116,-1000,-1000,201,154,19,6,1,10,17,0.39,58,1.6,95322,175; 3840,445,
        115,-1000,-1000,201,155,19,6,1,10,17,0.3,54,1.6,94171,175; 3900,444,116,
        -1000,-1000,200,155,19,6,1,10,17,0.42,53,1.5,93990,175; 3960,434,116,-1000,
        -1000,200,155,20,6,2,10,17,0.39,54,1.5,94081,175; 4020,422,115,-1000,-1000,
        200,156,19,5,3,10,16,0.3,56,1.5,95895,175; 4080,426,117,-1000,-1000,200,
        156,19,5,3,10,16,0.41,58,1.5,94252,175; 4140,432,123,-1000,-1000,200,157,
        19,6,3,10,17,0.55,60,1.5,93308,175; 4200,433,118,-1000,-1000,199,156,19,
        6,5,9,18,0.56,59,1.5,93203,175; 4260,433,124,-1000,-1000,199,155,19,6,7,
        10,17,0.42,58,1.5,92848,175; 4320,434,128,-1000,-1000,199,155,19,6,6,10,
        17,0.32,61,1.4,91926,175; 4380,436,130,-1000,-1000,198,154,19,6,6,10,17,
        0.38,64,1.5,92986,175; 4440,432,128,-1000,-1000,198,154,19,6,6,10,16,0.4,
        63,1.5,91967,174; 4500,423,126,-1000,-1000,198,154,19,6,6,10,16,0.4,61,1.4,
        92126,174; 4560,419,128,-1000,-1000,197,154,20,6,5,10,17,0.45,61,1.4,92203,
        174; 4620,416,131,-1000,-1000,197,154,19,6,6,10,17,0.46,61,1.4,91410,174;
        4680,417,129,-1000,-1000,197,155,19,6,7,10,16,0.32,61,1.4,92364,174; 4740,
        422,128,-1000,-1000,196,155,20,6,9,10,16,0.25,61,1.5,95096,174; 4800,428,
        133,-1000,-1000,196,155,19,6,11,10,16,0.38,62,1.5,93909,174; 4860,439,143,
        -1000,-1000,197,156,19,7,9,10,17,0.37,65,1.5,92215,174; 4920,439,146,-1000,
        -1000,197,156,19,6,6,8,19,0.41,66,1.5,92001,174; 4980,430,140,-1000,-1000,
        197,155,20,6,7,8,19,0.52,67,1.5,92889,174; 5040,424,136,-1000,-1000,196,
        155,20,7,8,9,18,0.58,71,1.5,92578,174; 5100,413,128,-1000,-1000,196,154,
        20,7,6,10,17,0.51,74,1.5,94973,174; 5160,413,129,-1000,-1000,196,154,19,
        7,5,10,17,0.4,75,1.6,94315,174; 5220,428,128,-1000,-1000,196,155,19,7,5,
        10,18,0.5,74,1.5,92763,174; 5280,433,125,-1000,-1000,196,155,19,7,7,9,19,
        0.55,68,1.6,93920,174; 5340,425,118,-1000,-1000,196,154,20,7,12,9,18,0.44,
        66,1.6,95238,174; 5400,416,112,-1000,-1000,196,154,19,8,11,10,17,0.39,65,
        1.6,94466,174; 5460,415,111,-1000,-1000,196,155,19,8,4,10,17,0.43,66,1.6,
        93063,174; 5520,412,111,-1000,-1000,196,155,19,8,3,10,18,0.41,68,1.6,96070,
        174; 5580,406,111,-1000,-1000,196,156,19,7,3,10,18,0.35,67,1.6,95126,174;
        5640,415,116,-1000,-1000,196,156,19,7,4,10,18,0.42,65,1.6,93883,174; 5700,
        425,114,-1000,-1000,196,156,19,7,4,9,19,0.46,65,1.7,94480,174; 5760,424,
        111,-1000,-1000,196,156,19,7,5,9,19,0.33,68,1.7,94897,174; 5820,415,106,
        -1000,-1000,196,155,20,7,5,10,18,0.26,70,1.7,96522,174; 5880,413,104,-1000,
        -1000,196,155,18,7,3,10,18,0.24,71,1.7,96762,174; 5940,412,106,-1000,-1000,
        197,155,18,7,2,10,19,0.17,70,1.7,95297,175; 6000,413,109,-1000,-1000,197,
        156,19,7,2,9,20,0.42,66,1.7,95516,175; 6060,408,107,-1000,-1000,197,156,
        19,6,3,9,19,0.52,65,1.7,97319,175; 6120,403,108,-1000,-1000,197,156,19,7,
        3,10,18,0.36,65,1.7,96156,175; 6180,403,110,-1000,-1000,197,156,19,7,3,10,
        19,0.49,61,1.8,95506,175; 6240,397,105,-1000,-1000,198,156,19,7,2,9,20,0.65,
        63,1.8,98084,175; 6300,393,104,-1000,-1000,198,155,19,7,3,9,19,0.37,76,1.8,
        97295,175; 6360,393,107,-1000,-1000,198,155,19,7,3,10,19,0.31,73,1.8,96387,
        175; 6420,390,105,-1000,-1000,198,155,19,7,3,10,19,0.58,66,1.8,97322,175;
        6480,385,98,-1000,-1000,198,155,19,7,4,10,19,0.49,75,1.8,99240,175; 6540,
        374,96,-1000,-1000,199,155,19,7,4,11,18,0.28,80,1.8,99073,175; 6600,368,
        99,-1000,-1000,199,156,19,8,2,11,18,0.38,72,1.9,98786,175; 6660,380,104,
        -1000,-1000,200,156,19,8,1,10,20,0.41,71,1.8,97380,175; 6720,392,105,-1000,
        -1000,200,156,19,7,2,9,20,0.46,74,1.8,97438,175; 6780,397,101,-1000,-1000,
        200,155,19,7,3,9,20,0.6,67,1.9,99470,175; 6840,399,101,-1000,-1000,200,155,
        19,7,4,10,19,0.52,60,1.9,98507,175; 6900,407,102,-1000,-1000,201,155,19,
        7,3,10,19,0.39,62,1.9,97618,175; 6960,410,97,-1000,-1000,201,155,19,7,3,
        10,19,0.44,65,1.9,98751,175; 7020,397,93,-1000,-1000,201,155,20,7,4,10,19,
        0.51,67,1.8,99580,175; 7080,392,95,-1000,-1000,201,155,19,7,3,11,18,0.44,
        68,1.9,99218,175; 7140,390,99,-1000,-1000,202,155,19,8,2,10,19,0.48,69,1.9,
        98906,175; 7200,389,99,-1000,-1000,202,155,20,7,3,10,19,0.53,72,1.9,99105,
        175; 7260,382,97,-1000,-1000,202,156,19,7,4,10,19,0.47,72,1.8,100345,175;
        7320,366,98,-1000,-1000,203,156,19,8,3,10,19,0.46,73,1.9,100181,175; 7380,
        375,104,-1000,-1000,203,156,19,8,2,10,19,0.38,75,1.9,99099,175; 7440,379,
        106,-1000,-1000,203,156,19,7,2,10,20,0.47,73,1.9,99657,175; 7500,378,105,
        -1000,-1000,204,156,19,7,5,9,19,0.51,68,1.8,99358,175; 7560,371,102,-1000,
        -1000,204,156,19,7,6,10,19,0.29,64,1.8,99645,175; 7620,358,100,-1000,-1000,
        204,155,20,7,5,10,18,0.18,63,1.9,99661,175; 7680,352,98,-1000,-1000,204,
        155,19,8,4,10,18,0.24,58,1.9,100403,175; 7740,343,95,-1000,-1000,204,155,
        19,8,5,10,19,0.51,58,1.9,100099,175; 7800,338,96,-1000,-1000,205,156,19,
        8,5,10,19,0.6,62,1.8,99213,175; 7860,335,97,-1000,-1000,205,156,19,8,4,10,
        19,0.39,64,1.8,99131,175; 7920,328,96,-1000,-1000,205,156,20,7,5,10,19,0.41,
        66,1.8,99662,175; 7980,325,94,-1000,-1000,205,156,20,8,7,10,18,0.47,70,1.8,
        99220,175; 8040,325,91,-1000,-1000,205,156,20,8,10,10,18,0.33,72,1.8,99819,
        175; 8100,323,92,-1000,-1000,205,156,19,8,8,10,19,0.3,73,1.9,99739,175])
    "HCl in, SO2 in, NO in,O2 in, T reactor in, T filter in, dp filter, HCl out, SO2 out, O2 out, H2O out, NH3 out, NO out, ash out, Vfluegas, T out"
    annotation (Placement(transformation(extent={{-84.32,143.12},{-64.32,163.12}},rotation = 0.0,origin = {0.0,0.0})));
  ThermalPower.FlueGasTreatment.Records.Data.InputData_BagReactor inputData(
    redeclare package Gas = Gas,
    Tstart=453.15,
    Cstart={inputData.C_in_no,0,inputData.C_in_so2,inputData.C_in_so2},
    vf={0.0845,0.18,0.074,0.6615,0},
    theta_am0=0)
    annotation (Placement(transformation(extent={{-118.32,145.12},{-98.32,165.12}},rotation = 0.0,origin = {0.0,0.0})));
  Modelica.Blocks.Sources.RealExpression C_in_data[Gas.nC](y=plantData_in.C_wet_uncorrected)
    annotation (Placement(transformation(extent={{-250,88},{-208,106}})));
  Modelica.Blocks.Sources.RealExpression X_in_data[Gas.nS](y=plantData_in.X_wet_uncorrected)
    annotation (Placement(transformation(extent={{-252,44},{-210,62}})));
  Modelica.Blocks.Sources.RealExpression m_flow_fluegas(y=plantData_in.m_flow_fluegas)
    annotation (Placement(transformation(extent={{-250,24},{-208,42}})));
  Modelica.Blocks.Sources.RealExpression T_in_data(y=plantData_in.T)
    annotation (Placement(transformation(extent={{-252,64},{-204,84}})));
  Modelica.Blocks.Continuous.LimPID PID_limewater(
    controllerType=Modelica.Blocks.Types.SimpleController.PI,
    k=0.5e-4,
    Ti=600,
    yMax=0.85,
    yMin=1e-4,
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    y_start=96/3600)
    annotation (Placement(transformation(extent={{72.0,-18.0},{52.0,2.0}},rotation = 0.0,origin = {0.0,0.0})));
  Modelica.Blocks.Sources.RealExpression HCl_data1(y=-20)
    annotation (Placement(transformation(extent={{158,-20},{110,0}})));
  Modelica.Blocks.Sources.RealExpression HCl_sim1(y=-concentration_out.y[9])
      annotation (Placement(transformation(extent={{158,-50},{110,-30}})));
  Modelica.Blocks.Sources.RealExpression m_flow_feed_s(y=84.57/3600)
    annotation (Placement(transformation(extent={{44,-42},{-4,-22}})));
  FlueGasTreatment.SubComponents.StoechiometryCoefficient SF_sim(
    n_pollutant_in=molarFlowSensor_in.nC_flow[3] + 0.5*molarFlowSensor_in.nC_flow[
        4],
    n_pollutant_out=n_SO2_filtered.y + 0.5*n_HCl_filtered.y,
    n_product_in=m_flow_feed_s.y*1000/74.01)
    annotation (Placement(transformation(extent={{-150,-22},{-130,-2}})));

   FlueGasTreatment.SubComponents.StoechiometryCoefficient SF_data(
    n_pollutant_in=plantData_in.nC_flow[3] + 0.5*plantData_in.nC_flow[4],
    n_pollutant_out=plantData_out.nC_flow[3] + 0.5*plantData_out.nC_flow[4],
    n_product_in=m_flow_feed_s.y*1000/74.01)
    annotation (Placement(transformation(extent={{-106,-22},{-86,-2}})));
  SubComponents.BagFilter.Bagfilter bagFilter(Cstart=Cstart, m_flow_start=
        inputData.m_flow_start)
    annotation (Placement(transformation(extent={{-59.0,24.0},{19.0,96.0}},rotation = 0.0,origin = {0.0,0.0})));
equation

  connect(molarFlowSensor_out.portB, concentration_out.portA) annotation (Line(
        points={{122,40},{174,40}},           color={85,170,255}));
  connect(concentration_out.y[8], SO2_filtered.u)
    annotation (Line(points={{182.2,51},{182.2,74},{204,74}},
                                                           color={0,0,127}));
  connect(n_SO2_filtered.u, molarFlowSensor_out.y[8]) annotation (Line(points={{144,84},
          {114.2,84},{114.2,51}},                    color={0,0,127}));
  connect(n_HCl_filtered.u, molarFlowSensor_out.y[9])
    annotation (Line(points={{150,120},{114.2,120},{114.2,51}},
                                                           color={0,0,127}));
  connect(molarFlowSensor_in.portB, concentration_in.portA)
    annotation (Line(points={{-138,40},{-120,40}},
                                                 color={85,170,255}));
  connect(concentration_out.portB, reservoir_mass_traces.port[1]) annotation (
      Line(points={{190,40},{214,40}},              color={85,170,255}));
  connect(flowsource_track_mass1.port, molarFlowSensor_in.portA)
    annotation (Line(points={{-168,38},{-168,40},{-154,40}},
                                                 color={85,170,255}));
  connect(flowsource_track_mass1.C_in, C_in_data.y) annotation (Line(points={{-168,46},
          {-168,97},{-205.9,97}},     color={0,0,127}));
  connect(flowsource_track_mass1.T_in, T_in_data.y) annotation (Line(points={{-173,46},
          {-173,74},{-201.6,74}},     color={0,0,127}));
  connect(X_in_data.y, flowsource_track_mass1.X_in) annotation (Line(points={{-207.9,
          53},{-178.6,53},{-178.6,46}}, color={0,0,127}));
  connect(m_flow_fluegas.y, flowsource_track_mass1.flow_in) annotation (Line(
        points={{-205.9,33},{-188,33},{-188,46},{-184,46}},
                                                          color={0,0,127}));
  connect(PID_limewater.u_m, HCl_filtered.y)
    annotation (Line(points={{62,-20},{62,-40},{71,-40}}, color={0,0,127}));
  connect(HCl_data1.y, PID_limewater.u_s) annotation (Line(points={{107.6,-10},{107.6,-8},{74,-8}}, color={0,0,127}));
  connect(HCl_sim1.y, HCl_filtered.u)
    annotation (Line(points={{107.6,-40},{94,-40}},color={0,0,127}));
  connect(LW_kgh.u, PID_limewater.y) annotation (Line(points={{18,12},{14,12},{14,-8},{51,-8}}, color={0,0,127}));
  connect(PID_limewater.y, sorbentSource.m_flow) annotation (Line(points={{51,-8},{14,-8},{14,2},{-32,2}}, color={0,0,127}));
  connect(bagFilter.sorbent_in, sorbentSource.sorbent) annotation (Line(points={{-54.32,87.36},{-64,87.36},{-64,1.8},{-51.8,1.8}}, color={28,
          108,200}));
  connect(concentration_in.portB,bagFilter. feed) annotation (Line(points={{-104,40},{-68,40},{-68,60.72},{-51.2,60.72}}, color={85,170,255}));
  connect(bagFilter.drain, molarFlowSensor_out.portA) annotation (Line(points={{11.200000000000003,60},{96,60},{96,40},{106,40}}, color={85,170,255}));
  annotation (experiment(
      StopTime=8100,
      __Dymola_NumberOfIntervals=5000,
      Tolerance=1e-07,
      __Dymola_Algorithm="Dassl"),
    Diagram(coordinateSystem(extent={{-280,-60},{240,140}})),
    __Dymola_experimentSetupOutput,
    Icon(coordinateSystem(extent={{-280,-60},{240,140}})));
end BagFilter_LW_SO2HCl;
