within FlueGasTreatment.Tests;
model SCR "SCR reactor with time-varying feed of NO and flue gas"
  extends Modelon.Icons.Experiment;
  import ThermalPower.FlueGasTreatment.Internal.Conversion.to_J;
import ThermalPower.FlueGasTreatment.Internal.Conversion.from_11oxygenDry;
 import ThermalPower.FlueGasTreatment.Internal.Conversion.from_Nm3;
  import ThermalPower.FlueGasTreatment.Internal.Conversion.to_11oxygenDry;
 replaceable package Gas =
      ThermalPower.FlueGasTreatment.Internal.Media.Gases.ReactionGas_withAsh
    constrainedby ThermalPower.SeparationProcess.Media.Gases.IdealFlueGas
                                                   annotation (
      choicesAllMatching=true);

  ThermalPower.FlueGasTreatment.Sources.Flowsource_mass_traces
    flowsource_track_mass1(
    connectorInput_flow=true,
    connectorInput_T=true,
    connectorInput_X=true,
    T0=473.15,
    C0={448*1e-6*2.29,0,0,0},
    redeclare package Fluid = Gas,
    connectorInput_C=true)
    annotation (Placement(transformation(extent={{-150,-16},{-130,4}})));
  ThermalPower.FlueGasTreatment.Sources.Reservoir_mass_traces
    reservoir_mass_traces(
    redeclare package Fluid = Gas,
    p0=100000,
    T0=493.15,
    N=1) annotation (Placement(transformation(extent={{174.5470763151403,-14.523411127395047},{154.5470763151403,5.476588872604953}},rotation = 0.0,origin = {0.0,0.0})));

  FlueGasTreatment.SubComponents.SCR SCR_reactor(
    redeclare package Gas = Gas,
    pstart=100000,
    Tstart=493.15,
    Xstart=Gas.reference_X,
    m_flow_start=10,
    Cstart={1e-6,0,0,0},
    redeclare record BedGeo = BedGeo,
    theta_am0=0.05,
    redeclare model Reaction =
        ThermalPower.FlueGasTreatment.DeNOx.Reaction.SCR_linearchange (
        
        diffusion_NH3=diffusion_NH3,
        diffusion_NO=diffusion_NO)) annotation (Placement(transformation(
        extent={{46.80730280460372,-13.479547021073106},{66.80730280460372,6.520452978926894}},
        rotation=0.0,
        origin={0.0,0.0})));

  Modelica.Blocks.Sources.RealExpression m_flow_fluegas(y=plantData_in.m_flow_fluegas)
    annotation (Placement(transformation(extent={{-216,-4},{-174,14}})));
  replaceable record BedGeo =
      FlueGasTreatment.Records.SCR_geo constrainedby FlueGasTreatment.Records.SCR_geo
    annotation (choicesAllMatching=true);
  ThermalPower.FlueGasTreatment.Volume.Mixer_ammonia SCR_mixer(
    redeclare package Fluid = Gas,
    p_start=110000,
    T_start=473.15) annotation (Placement(transformation(
        extent={{-91.57276935413324,-16.0},{-71.57276935413324,4.0}},
        rotation=0.0,
        origin={0.0,0.0})));
  parameter Real diffusion_NH3=4 "If>1 NH3 conc inside bed smaller than bulk";
  parameter Real diffusion_NO=1.5 "If>1 NO conc inside bed smaller than bulk";

  Modelica.Blocks.Continuous.LimPID PID(
    controllerType=Modelica.Blocks.Types.SimpleController.PI,
      k=1e-7,
    Ti=3600,
    Td=0,
    yMax=1e-5,
    yMin=0,
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    y_start=2e-6)    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={-50,44})));
  Modelica.Blocks.Sources.RealExpression NOx_sp(y=80) annotation (Placement(
        transformation(
        extent={{-24,-10},{24,10}},
        rotation=180,
        origin={8,66})));

  ThermalPower.SeparationProcess.Sensors.ConcentrationSensor concentration_out(
      redeclare package Fluid = Gas, concentrationType=ThermalPower.SeparationProcess.Sensors.Types.ConcentrationType.correctedNm3)
    annotation (Placement(transformation(extent={{124.54707631514029,-14.523411127395047},{144.5470763151403,5.476588872604953}},rotation = 0.0,origin = {0.0,0.0})));

  Modelica.Blocks.Sources.CombiTimeTable Tab_input(table=[0,215.13,211.56,8.17,6.37,167.31,69.99,5.14,24.73,5.52,6.91,19.07,40795.64;600,215.58,212.36,8.85,4.98,167.04,70.96,4.93,30.84,6.15,7.67,16.65,39756.17;1200,216.79,213.39,8.75,6.35,158.75,70.7,5.01,22.02,6.82,8.48,14.08,40883.97;1800,215.21,211.89,9.13,5.47,176.08,78.98,5,25.46,6.3,8.02,16.68,43701.25;2400,217.86,214.41,8.63,5.59,177.2,69.67,4.71,24.3,5.67,7.24,17.81,42188.69;3000,216.22,212.81,8.79,6.59,188.08,74.21,4.84,25.66,5.87,7.4,17.47,43268.19;3600,217.43,213.6,9.19,5.19,185.73,87.33,5.27,20.06,6.59,8.71,16.67,41830.02;4200,216.61,213.3,8.57,6.54,201.17,98.73,5.61,14.18,6.24,8.18,17.82,40746.98;4800,215.44,211.87,8.57,6.36,192.45,82.41,5.33,18.81,5.86,7.36,18.25,46729.59;5400,218.73,215.04,8.37,6.54,176.07,75.63,5.87,17.32,6.2,8.27,17.12,40777.13;6000,218.03,214.72,8.7,6.69,175.36,69.43,5.74,21.79,5.44,7.16,19.57,42226.44;6600,218.44,215.38,8.44,4.95,205.52,80.51,5.78,22.11,5.77,7.52,19.46,43021.4;7200,215.04,211.13,8.28,6.01,168.1,75.03,5.23,23.78,5.45,6.76,18.73,43908.79;7800,217.18,213.2,8.4,5.17,182.35,73.26,5.25,23.04,6.23,7.95,17.29,41393.12;8400,219.72,215.89,8.46,5.67,158.82,77.38,5.91,16.91,7.39,9.37,15.86,34774.96;9000,218.53,215.26,8.76,5.82,181.73,91.9,6.24,13.02,6.97,9.23,15.81,39672.94;9600,216.06,212.19,8.91,5.91,168.67,73.39,5.33,19.18,5.89,7.21,18.14,45244.59;10200,215.94,212.87,8.95,5.97,186.21,74.18,4.92,30.16,5.33,6.92,17.76,43599.77;10800,215.24,211.39,9.1,6.48,194.27,76.61,4.96,24.75,5.51,7,18.05,45162.89;11400,220.86,217.1,8.8,5.21,198.31,84.25,5.11,20.59,5.76,7.4,18.21,44276.73;12000,218.78,215.33,12.62,5.99,184.81,78.04,4.88,17.98,5.8,7.34,18.26,41920.57;12600,219.14,215.51,18.02,6.06,182.47,75.62,5,22.54,5.44,7.27,17.94,39847.4;13200,219.16,215.51,17.46,6.05,189.09,77.84,5.34,17.07,5.5,7.35,18.66,46839.45;13800,216.46,212.65,11.12,6.46,193.22,77.77,5.55,20.98,5.75,7.09,19.18,44450.9;14400,220.9,217.28,12.6,6.38,188.44,75.96,5.55,18.66,5.65,7.31,18.42,42827.43;15000,218.74,215.74,18.83,5.01,202.62,76.81,5.44,24.03,5.4,6.98,18.76,47225.62;15600,220.34,216.72,16.98,5.97,223.08,86.96,5.09,27.02,5.61,6.94,17.66,42750.9;16200,219.71,216.07,14.18,4.89,175.24,75.5,5.61,24.35,6.58,7.94,17.17,42131.1;16800,219.38,215.39,10.56,6.12,179.82,79.13,5.73,22.63,5.93,7.76,18.11,40630.82;17400,215.43,211.85,10.55,5.84,184.74,72.71,5.11,16.76,5.37,6.74,18.79,43887.54;18000,216.09,213.05,11.81,5.93,192.79,82.3,4.98,37.88,5.74,7.21,18.93,44412.46;18600,216.84,213.21,16.8,5.88,195.08,79.43,4.98,13.56,5.83,7.69,18.03,43766.69;19200,220.21,216.7,17.34,5.95,194.18,74.3,5.12,26.12,6,7.47,17.82,38798.13;19800,215.02,211.34,15.21,5.52,202.94,85.4,5.33,16.62,5.94,7.81,17.99,46220.09;20400,215.3,212.19,10.18,6,197.73,94.21,5.76,18.01,6.62,8.34,17.95,42953.94;21000,217.26,213.39,10.02,6.7,180.37,77.41,5.49,21.56,5.94,7.49,18.39,40875.71;21600,216.53,213.29,10.39,5.97,190.54,70.76,5.24,28.52,5.52,6.86,18.22,45665.27;22200,215.71,211.85,13.2,5.13,203.14,82.43,5.16,25.97,6.22,7.26,17.37,42127.57;22800,217.34,213.65,15.14,5.8,178.87,71.87,5.09,17.68,6.28,7.7,17.9,42446.14;23400,220.1,216.1,18.34,6.02,191.82,91.27,5.44,25.99,6.61,7.87,18.5,44238.76;24000,218.83,215.8,15.94,4.97,205.11,85.22,5.05,22.27,5.46,6.75,19.22,45370.79;24600,218.13,214.82,17.97,4.97,219.2,94.57,4.86,35.36,5.6,6.87,19.98,43991.77;25200,218.04,214.93,18.14,5.94,219.38,81.73,4.86,18.35,5.39,6.56,19.05,45357.49;25800,216.25,212.46,18.18,4.96,222.12,85.31,5.1,25.04,5.79,7.42,16.36,41766.33;26400,216.01,212.46,11.9,5.07,194.25,76.58,5.26,17.23,5.85,7.57,17.47,41847.96;27000,217.16,213.33,12.65,5.18,181.34,73.27,5.56,17.16,5.17,6.53,20.54,41845.66;27600,218.41,214.89,12.38,6.07,172.23,69.67,5.46,19.53,5.68,7.24,18.91,41361.17;28200,220.95,217.53,17.56,6.25,175.05,70.31,5.24,23.93,5.54,6.88,19.65,45750.04;28800,219.1,215.39,6.84,6.53,153.83,70.43,4.57,32.97,5.7,6.86,18.96,41782.08;29400,218.14,214.95,10.12,6.18,173.45,75.28,4.59,17,5.7,7.2,19,44194.33;30000,216.53,212.76,11.56,6.48,196.14,79.33,4.58,33.28,5.77,7.17,18.91,44403.15;30600,219.87,215.92,18.06,6.56,223.04,89.37,4.3,29.53,5.64,6.76,18.24,42259.07;31200,216.6,213.19,17.8,5.7,195.52,72.81,4.53,17.71,5.95,7.63,15.57,41124.16;31800,216.6,212.83,18.22,4.99,188.33,69.02,5.31,30.42,6.52,7.99,16.41,42641.18;32400,218.92,215.73,18.03,6.45,207.47,98.17,6.04,12.6,6.75,8.82,16.67,40779.49;33000,216.27,212.36,17.89,5.83,203.74,100.17,5.71,11.45,5.44,7.31,19.47,44388.52;33600,219.76,216.19,15.66,6.18,191.3,84.6,5.12,12.19,5.27,7.01,19.68,43026.69;34200,218.93,215.13,9.93,6.63,183.61,84.55,5.37,13.78,6.34,7.87,18.32,41098.08;34800,220.3,216.6,13.12,5.05,170.05,73.52,5.72,20.04,5.97,7.8,18.99,43803.07;35400,218.71,215.66,17.48,5.2,163.92,70.98,5.4,28.76,6,8.09,17.58,39227.5;36000,217.36,213.68,10.37,5.37,156.88,73.12,5.27,25.08,6.36,8.29,17,38543.15;36600,217.13,213.9,10.39,5.68,170.08,74.15,5.03,18.04,5.85,7.72,18.12,43861.23;37200,216.62,213.46,10.48,5.32,184.18,87.06,4.68,26.51,6.41,8.08,17.16,43050.48;37800,219.62,215.71,12.27,6.36,179.03,94.66,4.83,23.66,6.77,8.59,16.64,40381.08;38400,215.19,211.21,16.63,5.26,187.87,95.2,4.71,23.24,5.98,7.87,16.88,45065.09;39000,217.35,213.74,16.71,6.39,179.4,79.78,4.46,22.9,5.44,6.71,17.96,44616.77;39600,217.33,213.99,17.61,6.69,182.82,88.61,4.22,33.68,5.64,7.05,17.89,43898.8;40200,215.83,212.35,10.53,5.38,198.7,80.77,3.99,26.8,5.93,7.11,16.35,44686.4;40800,215.7,212.01,9.81,5.32,183.21,76.11,4.17,11.48,6.03,7.43,15.86,42807.88;41400,219.89,216.24,14.39,5.2,190.63,65.48,4.28,33.67,5.07,6.35,18.27,41638.42;42000,216.13,212.75,17.94,6.63,225.66,90.16,4.21,15.05,5.83,7.06,16.87,41656.09])
    "Temp in, Temp out, NH4OH, dp, NOx in, Nox out, NH3 out, SO2 in, O2 in, O2 out, H2O in, Vlfuegas"                                                                                                       annotation (Placement(transformation(extent={{-102.0,100.0},{-82.0,120.0}},rotation = 0.0,origin = {0.0,0.0})));
  Modelica.Blocks.Sources.RealExpression T_in_data(y=plantData_in.T)
    annotation (Placement(transformation(extent={{-216.0,35.514020508334546},{-168.0,55.514020508334546}},rotation = 0.0,origin = {0.0,0.0})));

  FlueGasTreatment.Records.InputData plantData_in(
    p=100300,
    V_flow_fluegas=Tab_input.y[12],
    T=Tab_input.y[2] + 273,
    T_chimney=Tab_input.y[1] + 273.15,
    c_H2O_chimney=Tab_input.y[11],
    c_CO2=8,
    c_H2O=Tab_input.y[11],
    c_O2=Tab_input.y[10],
    c_ash=0,
    c_NO=Tab_input.y[5],
    c_SO2=0,
    c_HCl=0)
    annotation (Placement(transformation(extent={{-72.33333333333334,99.66666666666667},{-52.333333333333336,119.66666666666667}},rotation = 0.0,origin = {0.0,0.0})));
  FlueGasTreatment.Records.InputData plantData_out(
    V_flow_fluegas=Tab_input.y[12],
    T=Tab_input.y[1] + 273,
    T_chimney=Tab_input.y[2] + 273.15,
    c_H2O_chimney=Tab_input.y[11],
    c_CO2=8,
    c_H2O=Tab_input.y[11],
    c_O2=Tab_input.y[10],
    c_ash=0,
    c_NO=Tab_input.y[6],
    c_NH3=Tab_input.y[7],
    c_SO2=Tab_input.y[8],
    c_HCl=0)
    annotation (Placement(transformation(extent={{-44.333333333333336,99.66666666666667},{-24.333333333333336,119.66666666666667}},rotation = 0.0,origin = {0.0,0.0})));
  Modelica.Blocks.Sources.RealExpression X_in_data[Gas.nS](y=plantData_in.X_wet_uncorrected)
    annotation (Placement(transformation(extent={{-216,16},{-174,34}})));
  Modelica.Blocks.Sources.RealExpression C_in_data[Gas.nC](y=plantData_in.C_wet_uncorrected)
    annotation (Placement(transformation(extent={{-214,56},{-172,74}})));
  FlueGasTreatment.SubComponents.StoechiometryCoefficient SF_sim(
    n_pollutant_in=molarFlowSensor_in.nC_flow[1],
    n_pollutant_out=molarFlowSensor_out.nC_flow[1],
    n_product_in=molarFlowSensor_in.nC_flow[2])
    annotation (Placement(transformation(extent={{-16.333333333333336,99.66666666666667},{3.666666666666666,119.66666666666667}},rotation = 0.0,origin = {0.0,0.0})));
  FlueGasTreatment.SubComponents.StoechiometryCoefficient SF_data(
    n_pollutant_in=plantData_in.nC_flow[1],
    n_pollutant_out=plantData_out.nC_flow[1],
    n_product_in=Tab_input.y[3]/3.6e3*910*0.245/17)
    annotation (Placement(transformation(extent={{11.666666666666664,99.66666666666667},{31.666666666666664,119.66666666666667}},rotation = 0.0,origin = {0.0,0.0})));
  FlueGasTreatment.Records.Summary summary(
    Ash_sim=concentration_out.y[5],
    NOx_sim=concentration_out.y[6],
    NH3_sim=concentration_out.y[7],
    SO2_sim=concentration_out.y[8],
    HCl_sim=concentration_out.y[9])
    annotation (Placement(transformation(extent={{55.66666666666667,101.66666666666667},{75.66666666666667,121.66666666666667}},rotation = 0.0,origin = {0.0,0.0})));
    .ThermalPower.FlueGas.FlowResistances.FrictionLoss frictionLoss2(redeclare
      model Friction =
        .Modelon.ThermoFluid.FlowResistances.FrictionModels.QuadraticOperatingPointLoss
        (m_flow0=16),                                                                                                                                                           redeclare
      package Medium =                                                                                                                                                                                     Gas) annotation(Placement(transformation(extent = {{72.54707631514029,-14.523411127395047},{92.54707631514029,5.476588872604953}},rotation = 0.0,origin = {0.0,0.0})));
      ThermalPower.SeparationProcess.Sensors.MolarFlowSensor molarFlowSensor_out(redeclare
      package Fluid =                                                                                      Gas) annotation(Placement(transformation(extent = {{98.54707631514029,-14.523411127395047},{118.54707631514029,5.476588872604953}},rotation = 0.0,origin = {0.0,0.0})));
      ThermalPower.SeparationProcess.Sensors.MolarFlowSensor molarFlowSensor_in(redeclare
      package Fluid =                                                                                     Gas) annotation(Placement(transformation(extent = {{18.286849825676885,-15.304090595785382},{38.28684982567688,4.695909404214618}},rotation = 0.0,origin = {0.0,0.0})));
      ThermalPower.SeparationProcess.Sensors.ConcentrationSensor concentration_in(redeclare
      package Fluid =                                                                                       Gas,concentrationType = ThermalPower.SeparationProcess.Sensors.Types.ConcentrationType.correctedNm3) annotation(Placement(transformation(extent = {{-60.12440844991315,-15.999999999999993},{-40.12440844991315,4.000000000000007}},rotation = 0.0,origin = {0.0,0.0})));
      .ThermalPower.FlueGas.FlowResistances.FrictionLoss frictionLoss(redeclare
      package Medium =                                                                           Gas,redeclare
      model Friction =
        .Modelon.ThermoFluid.FlowResistances.FrictionModels.QuadraticOperatingPointLoss)
                                                                                                                                                                                                            annotation(Placement(transformation(extent = {{-17.32926219327497,-15.198020979904294},{2.6707378067250307,4.801979020095706}},rotation = 0.0,origin = {0.0,0.0})));

equation

  connect(concentration_out.portB, reservoir_mass_traces.port[1]) annotation (
      Line(points={{142.547,-4.52341},{146,-4.52341},{146,-4},{149.74,-4},{
          149.74,-4.52341},{156.547,-4.52341}},                                                                      color={85,170,255}));
  connect(NOx_sp.y, PID.u_m)
    annotation (Line(points={{-18.4,66},{-50,66},{-50,56}}, color={0,0,127}));
  connect(T_in_data.y, flowsource_track_mass1.T_in) annotation (Line(points={{-165.6,45.514020508334546},{-137,45.514020508334546},{-137,2}}, color={0,0,127}));
    connect(concentration_out.y[6], PID.u_s)
      annotation (Line(points={{134.74707631514028,6.476588872604953},{134.74707631514028,44},{-38,44}},color={0,0,127}));
  connect(m_flow_fluegas.y, flowsource_track_mass1.flow_in) annotation (Line(
        points={{-171.9,5},{-171.9,2},{-148,2}}, color={0,0,127}));
  connect(X_in_data.y, flowsource_track_mass1.X_in) annotation (Line(points={{-171.9,
          25},{-142.6,25},{-142.6,2}}, color={0,0,127}));
  connect(C_in_data.y, flowsource_track_mass1.C_in) annotation (Line(points={{-169.9,65},{-132,65},{-132,2}},
                                   color={0,0,127}));
  connect(PID.y, SCR_mixer.solution_volume_flow) annotation (Line(points={{-61,44},{-88.17276935413324,44},{-88.17276935413324,4.4}},
                                      color={0,0,127}));
    connect(SCR_reactor.drain,frictionLoss2.feed) annotation(Line(points={{65.0073,
          -3.47955},{68,-3.47955},{68,-4.52341},{72.5471,-4.52341}},                                                                                         color = {85,170,255}));
      connect(molarFlowSensor_out.portB,concentration_out.portA) annotation(Line(points={{116.547,
          -4.52341},{116.547,-4.52341},{121.74,-4.52341},{121.74,-5.56727},{
          121.74,-4.52341},{126.547,-4.52341}},                                                                                                                               color = {85,170,255}));
      connect(frictionLoss2.drain,molarFlowSensor_out.portA) annotation(Line(points={{92.5471,
          -4.52341},{92.5471,-4.52341},{97.7398,-4.52341},{97.7398,-5.56727},{
          97.7398,-4.52341},{100.547,-4.52341}},                                                                                                                        color = {85,170,255}));
      connect(molarFlowSensor_in.portB,SCR_reactor.feed) annotation(Line(points = {{36.28684982567688,-5.304090595785382},{42.5470763151403,-5.304090595785382},{42.5470763151403,-3.479547021073106},{48.80730280460372,-3.479547021073106}},color = {85,170,255}));
      connect(concentration_in.portA,SCR_mixer.drain) annotation(Line(points = {{-58.12440844991315,-5.999999999999993},{-67.24040771045244,-5.999999999999993},{-67.24040771045244,-6},{-73.57276935413324,-6}},color = {85,170,255}));
      connect(frictionLoss.drain,molarFlowSensor_in.portA) annotation(Line(points = {{2.6707378067250307,-5.198020979904294},{8.281548911013925,-5.198020979904294},{8.281548911013925,-5.304090595785382},{20.28684982567688,-5.304090595785382}},color = {0,191,0}));
      connect(frictionLoss.feed,concentration_in.portB) annotation(Line(points = {{-17.32926219327497,-5.198020979904294},{-34.315899035210336,-5.198020979904294},{-34.315899035210336,-5.999999999999993},{-42.12440844991315,-5.999999999999993}},color = {0,191,0}));
      connect(SCR_mixer.feed,flowsource_track_mass1.port) annotation(Line(points = {{-89.57276935413324,-6},{-132,-6}},color = {85,170,255}));
  annotation (experiment(
      StopTime=7200,
      Tolerance=1e-07,
      __Dymola_Algorithm="Cvode"),
      Diagram(coordinateSystem(extent={{-260,-20},{120,120}})),
    Documentation(info="<html>
<p>Example for <a href=\"modelica://ThermalPower.FlueGasTreatment.DeNOx.SCR\">SCR reactor</a>  at low temperature of ~500K and pressure of ~1 bar with linear feeding of ammonia and constant feeding of NO.</p>


</html>"));
end SCR;
